#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 req
version:              3.13.4
visibility:           public
id:                   req-3.13.4-8BmuPEjKDlU1QeDcWxFVnp
key:                  req-3.13.4-8BmuPEjKDlU1QeDcWxFVnp
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/req
synopsis:             HTTP client library
description:          HTTP client library.
category:             Network, Web
abi:                  063b95964ac9b170a7e3bd41fe882564
exposed:              True
exposed-modules:      Network.HTTP.Req
import-dirs:          /usr/lib/ghc-9.6.6/site-local/req-3.13.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/req-3.13.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/req-3.13.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-req
hs-libraries:         HSreq-3.13.4-8BmuPEjKDlU1QeDcWxFVnp
depends:
    aeson-2.2.1.0-JgWKiJCfYvV9emVBTyf17S
    authenticate-oauth-1.7-BcnNs1HPKOXJgqOmTwESYC base-4.18.2.1
    blaze-builder-0.4.4.1-FueEPpNIqsb4bYeizJE1KI bytestring-0.11.5.3
    case-insensitive-1.2.1.0-GQhuCOunwpP4Wu7eC91bZR containers-0.6.7
    crypton-connection-0.4.5-KUI4yWmqX4KWhzdqcE5Ci
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc exceptions-0.10.7
    http-api-data-0.6.1-G3S5J8YnkodFPxBwPXBbso
    http-client-0.7.19-A1qGvj2MlivKXlcAABR34l
    http-client-tls-0.3.6.4-3iqTlLw34e0FRUZYw5kJuu
    http-types-0.12.4-CCQmPdMOAQMGVpO7SZrjGJ
    modern-uri-0.3.6.1-7ZIZ8nWqnD1CocG4G1Y3OX
    monad-control-1.0.3.1-3aesjSnNbBPBO9xROInTTp mtl-2.3.1
    retry-0.9.3.1-Em8OXhcO1BnFSqwIXyQqas template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    transformers-base-0.4.6.1-EhoPgmv9LMnFdOplZHTQBi
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-req/html/req.haddock
haddock-html:         /usr/share/doc/haskell-req/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

